HuxDropdown<T> class
A dropdown/select component with overlay-based options list.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- HuxDropdown
Constructors
-
HuxDropdown({Key? key, required List<
HuxDropdownItem< items, T? value, ValueChanged<T> >T> ? onChanged, String placeholder = 'Select option', HuxButtonVariant variant = HuxButtonVariant.outline, HuxButtonSize size = HuxButtonSize.medium, Color? primaryColor, bool enabled = true, double maxHeight = 200, bool useItemWidgetAsValue = false}) -
Creates a dropdown component.
const
Properties
- enabled → bool
-
Whether the dropdown is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
HuxDropdownItem< T> > -
List of dropdown items
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxHeight → double
-
Maximum height of the dropdown panel
final
-
onChanged
→ ValueChanged<
T> ? -
Called when selection changes
final
- placeholder → String
-
Placeholder text when no value selected
final
- primaryColor → Color?
-
Optional primary color override
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → HuxButtonSize
-
Size of the trigger button
final
- useItemWidgetAsValue → bool
-
Whether to use the item widget as the value representation
final
- value → T?
-
Currently selected value
final
- variant → HuxButtonVariant
-
Visual style of the trigger button
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< HuxDropdown< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited