HuxSidebar class
A complete sidebar navigation component that manages multiple navigation items.
Provides a consistent sidebar layout with header, navigation items, and optional footer. Handles selection state management and provides a clean API for sidebar navigation.
Example:
HuxSidebar(
header: Column(
children: [
Text('My App'),
Text('Navigation'),
],
),
items: [
HuxSidebarItemData(
id: 'dashboard',
icon: LucideIcons.home,
label: 'Dashboard',
),
HuxSidebarItemData(
id: 'settings',
icon: LucideIcons.settings,
label: 'Settings',
),
],
selectedItemId: 'dashboard',
onItemSelected: (itemId) => print('Selected: $itemId'),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- HuxSidebar
Constructors
-
HuxSidebar({Key? key, required List<
HuxSidebarItemData> items, required ValueChanged<String> onItemSelected, String? selectedItemId, Widget? header, double width = 250, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(vertical: 16)}) -
Creates a HuxSidebar widget.
const
Properties
-
Optional footer widget displayed at the bottom
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
Optional header widget displayed at the top
final
-
items
→ List<
HuxSidebarItemData> -
List of navigation items to display
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onItemSelected
→ ValueChanged<
String> -
Callback when an item is selected
final
- padding → EdgeInsetsGeometry
-
Padding around the sidebar content
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItemId → String?
-
Currently selected item ID
final
- width → double
-
Width of the sidebar
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited